
Imports System.Environment
Module ModDir
    Private Declare Function GetSystemDirectory Lib "kernel32" Alias "GetSystemDirectoryA" (ByVal lpBuffer As String, ByVal nSize As Integer) As Integer
    Private Declare Function GetLongPathName Lib "kernel32" Alias "GetLongPathNameA" (ByVal lpszShortPath As String, ByVal lpszLongPath As String, ByVal cchBuffer As Integer) As Integer
    Private Declare Function GetWindowsDirectory Lib "kernel32" Alias "GetWindowsDirectoryA" (ByVal lpBuffer As String, ByVal nSize As Integer) As Integer
    Private Declare Function GetShortPathName Lib "kernel32" Alias "GetShortPathNameA" (ByVal lpszLongPath As String, ByVal lpszShortPath As String, ByVal cchBuffer As Long) As Integer
    Private Declare Function GetTempFileName Lib "kernel32" Alias "GetTempFileNameA" (ByVal lpszPath As String, ByVal lpPrefixString As String, ByVal wUnique As Integer, ByVal lpTempFilename As String) As Integer

    Public Function GetSpecialFolder(ByVal mFolder As Environment.SpecialFolder) As String
        GetSpecialFolder = Environment.GetFolderPath(mFolder)
    End Function

    Public Function GetWindowsFolder(Optional ByVal LongPath As Boolean = False) As String
        Dim sBuffer As String
        sBuffer = New String(" ", 200)
        GetWindowsDirectory(sBuffer, 200)
        If LongPath Then
            Return RemoveBackSlash(GetLongPath(StripTerminator(sBuffer)))
        Else
            Return RemoveBackSlash(StripTerminator(sBuffer))
        End If
    End Function

    Public Function GetSystemFolder(Optional ByVal LongPath As Boolean = False) As String
        Dim sBuffer As String
        sBuffer = New String(" ", 200)
        GetSystemDirectory(sBuffer, 200)
        If LongPath Then
            Return RemoveBackSlash(GetLongPath(StripTerminator(sBuffer)))
        Else
            Return RemoveBackSlash(StripTerminator(sBuffer))
        End If
    End Function

    Public Function GetTempFolder(Optional ByVal LongPath As Boolean = False) As String
        If LongPath Then
            Return RemoveBackSlash(GetLongPath(System.IO.Path.GetTempPath))
        Else
            Return RemoveBackSlash(System.IO.Path.GetTempPath)
        End If
    End Function

    Public Function FileExists(ByVal mPath As String) As Boolean
        Return System.IO.File.Exists(mPath)
    End Function

    Public Function FolderExists(ByVal mPath As String) As Boolean
        Return System.IO.Directory.Exists(mPath)
    End Function

    Public Function FileOnly(ByVal mPath As String, Optional ByVal WithoutExtension As Boolean = False) As String
        Dim Ret As String = mPath
        If WithoutExtension Then
            Ret = System.IO.Path.GetFileNameWithoutExtension(mPath)
        Else
            Ret = System.IO.Path.GetFileName(mPath)
        End If
        Return Ret
    End Function

    Public Function PathOnly(ByVal mPath As String) As String
        Return System.IO.Path.GetDirectoryName(mPath)
    End Function

    Public Function FolderNameOnly(ByVal mPath As String) As String
        Return FileOnly(System.IO.Path.GetDirectoryName(mPath))
    End Function

    Public Function ExtOnly(ByVal mPath As String, Optional ByVal WithoutDot As Boolean = False) As String
        Dim Ret As String = ""
        Ret = System.IO.Path.GetExtension(mPath)
        If WithoutDot Then Ret = Ret.TrimStart(".")
        Return Ret
    End Function

    Public Function ChangeExt(ByVal mPath As String, Optional ByVal NewExt As String = "") As String
        Return System.IO.Path.ChangeExtension(mPath, NewExt)
    End Function

    Public Function GetTempFile(Optional ByVal mPrefix As String = "bb", Optional ByVal AlternateTempPath As String = "") As String
        Dim lpTempFilename As String, mdir As String
        lpTempFilename = New String(" ", 255)
        If AlternateTempPath = "" Then AlternateTempPath = GetTempFolder()
        GetTempFileName(AlternateTempPath, mPrefix, 0, lpTempFilename)
        GetTempFile = StripTerminator(lpTempFilename)
    End Function


    Public Function StripTerminator(ByVal mString As String) As String
        Dim z As Integer = mString.IndexOf(Chr(0))
        If z > -1 Then
            Return mString.Remove(z, mString.Length - z)
        Else
            Return mString
        End If
    End Function

    Public Function GetLongPath(ByVal sShortFilename As String) As String
        Dim lRet As Integer
        Dim sLongFilename As String
        sLongFilename = New String(" ", 1024)
        lRet = GetLongPathName(sShortFilename, sLongFilename, sLongFilename.Length)
        Return StripTerminator(sLongFilename)
    End Function

    Public Function GetShortPath(ByVal LongPath As String) As String
        Dim temp As String
        Dim z As Integer
        z = LongPath.Length + 1
        temp = New String(Chr(0), LongPath.Length + 1)
        GetShortPathName(LongPath, temp, LongPath.Length + 1)
        Return StripTerminator(temp)
    End Function

    Public Function RemoveBackSlash(ByVal mPath As String) As String
        If mPath.EndsWith("\") Then
            Return mPath.Remove(mPath.Length - 1, 1)
        Else
            Return mPath
        End If
    End Function

    Public Function AddBackSlash(ByVal mPath As String) As String
        If mPath.EndsWith("\") Then
            Return mPath
        Else
            Return mPath & "\"
        End If
    End Function

    Public Function AppPath() As String
        Dim tmp$
        tmp$ = Application.StartupPath
        AppPath = AddBackSlash(tmp$)
    End Function

    Public Function GetVersion() As String
        Dim osInfo As OperatingSystem

        osInfo = OSVersion 'Imports System.Environment (Oben)

        With osInfo
            Select Case .Platform

                Case .Platform.Win32Windows
                    Select Case (.Version.Minor)
                        Case 0
                            Return "Windows 95"
                        Case 10
                            If .Version.Revision.ToString() = "2222A" Then
                                Return "Windows 98 Second Edition"
                            Else
                                Return "Windows 98"
                            End If
                        Case 90
                            Return "Windows Me"
                    End Select

                Case .Platform.Win32NT
                    Select Case (.Version.Major)
                        Case 3
                            Return "Windows NT 3.51"
                        Case 4
                            Return "Windows NT 4.0"
                        Case 5
                            Select Case (.Version.Minor)
                                Case 0
                                    Return "Windows 2000"
                                Case 1
                                    Return "Windows XP"
                                Case 2
                                    Return "Windows Server 2003"
                            End Select
                        Case Else
                            Return "Failed"
                    End Select
            End Select
        End With
    End Function

End Module
